@@ -22,7 +22,7 @@ impl<T: Clone, const N: usize> Clone for StaticHeap<T, N> {
 
 // This allows `StaticHeap` to benefit from the optimized
 // "Clone for Copy types" impl that `StaticVec` has.
-impl<T: Copy, const N: usize> Clone for StaticHeap<T, N> {
+impl<T: Copy, const N: usize> const Clone for StaticHeap<T, N> {
   #[inline(always)]
   fn clone(&self) -> Self {
     StaticHeap {
@@ -188,7 +188,7 @@ impl<'a, T: 'a + Copy + Ord, const N: usize> FromIterator<&'a T> for StaticHeap<
   }
 }
 
-impl<T, const N: usize> IntoIterator for StaticHeap<T, N> {
+impl<T, const N: usize> const IntoIterator for StaticHeap<T, N> {
   type Item = T;
   type IntoIter = StaticVecIntoIter<T, N>;
 
@@ -214,7 +214,7 @@ impl<T, const N: usize> IntoIterator for StaticHeap<T, N> {
   }
 }
 
-impl<'a, T, const N: usize> IntoIterator for &'a StaticHeap<T, N> {
+impl<'a, T, const N: usize> const IntoIterator for &'a StaticHeap<T, N> {
   type Item = &'a T;
   type IntoIter = StaticVecIterConst<'a, T, N>;
 
@@ -224,7 +224,7 @@ impl<'a, T, const N: usize> IntoIterator for &'a StaticHeap<T, N> {
   }
 }
 
-impl<'a, T, const N: usize> IntoIterator for &'a mut StaticHeap<T, N> {
+impl<'a, T, const N: usize> const IntoIterator for &'a mut StaticHeap<T, N> {
   type Item = &'a mut T;
   type IntoIter = StaticVecIterMut<'a, T, N>;
 
